@@ -1,6 +1,9 @@
 funnel.meta <- function(x,
+                        ##
                         xlim=NULL, ylim=NULL, xlab=NULL, ylab=NULL,
+                        ##
                         comb.fixed=x$comb.fixed, comb.random=x$comb.random,
+                        ##
                         axes=TRUE,
                         pch=if (!inherits(x, "trimfill")) 21 else ifelse(x$trimfill, 1, 21),
                         text=NULL, cex=1,
@@ -8,72 +11,96 @@ funnel.meta <- function(x,
                         lwd=1, lwd.fixed=lwd, lwd.random=lwd,
                         col="black", bg="darkgray",
                         col.fixed="black", col.random="black",
+                        ##
                         log="", yaxis="se",
                         contour.levels=NULL, col.contour,
+                        ##
                         ref=ifelse(backtransf & is.relative.effect(x$sm), 1, 0),
+                        ##
                         level=x$level,
                         studlab=FALSE, cex.studlab=0.8,
+                        ##
                         backtransf=x$backtransf,
                         ...){
   
-  if (!inherits(x, "meta"))
-    stop("Argument 'x' must be an object of class \"meta\"")
   
+  ##
+  ##
+  ## (1) Check for meta object and upgrade older meta object
+  ##
+  ##
+  chkclass(x, "meta")
+  ##
   if (inherits(x, "metacum"))
     stop("Funnel plot not meaningful for object of class \"metacum\"")
   ##
   if (inherits(x, "metainf"))
     stop("Funnel plot not meaningful for object of class \"metainf\"")
-  
-  
-  ## Upgrade meta objects created with older versions of meta
   ##
-  if (!(!is.null(x$version) &&
-        as.numeric(unlist(strsplit(x$version, "-"))[1]) >= 3.8))
-    x <- update(x, warn=FALSE)
+  x <- updateversion(x)
   
   
+  ##
+  ##
+  ## (2) Check other arguments
+  ##
+  ##
+  chklogical(comb.fixed)
+  chklogical(comb.random)
+  chklogical(axes)
+  chknumeric(cex)
+  chknumeric(lty.fixed)
+  chknumeric(lty.random)
+  chknumeric(lwd)
+  chknumeric(lwd.fixed)
+  chknumeric(lwd.random)
+  yaxis <- setchar(yaxis, c("se", "size", "invvar", "invse"))
+  if (!is.null(contour.levels))
+    chklevel(contour.levels, single=FALSE, ci=FALSE)
+  chknumeric(ref)
+  if (!is.null(level))
+    chklevel(level)
+  chknumeric(cex.studlab)
+  chklogical(backtransf)
+  
+  
+  ##
+  ##
+  ## (3) Check length of essential variables
+  ##
+  ##
   TE <- x$TE
+  k.All <- length(TE)
   seTE <- x$seTE
+  seTE[is.infinite(seTE)] <- NA
+  ##
+  if (is.logical(studlab))
+    if (studlab){
+      slab <- TRUE
+      studlab <- x$studlab
+    }
+    else
+      slab <- FALSE
+  else
+    slab <- TRUE
+  ##
+  fun <- "funnel"
+  chklength(seTE, k.All, fun)
+  if (slab)
+    chklength(studlab, k.All, fun)
+  if (!is.null(text))
+    chklength(text, k.All, fun)
+  
+  
+  ##
+  ##
+  ## (4) Further assignments
+  ##
+  ##
   TE.fixed <- x$TE.fixed
   TE.random <- x$TE.random
   sm <- x$sm
-  if (is.logical(studlab) && studlab)
-    studlab <- x$studlab
-  
-  if (length(comb.fixed)==0){
-    comb.fixed <- FALSE
-  }
-  ##
-  if (length(comb.random)==0){
-    comb.random <- FALSE
-  }
-  ##
-  if (length(level)==0){
-    level <- NULL
-  }
-  
-  
-  if(length(TE) != length(seTE))
-    stop("length of argument TE and seTE must be equal")
-  
-  if (!is.null(level) && (level<=0|level>=1))
-    stop("no valid level for confidence interval")
-  
-  if (!is.null(contour.levels) &&
-      any(contour.levels<=0|contour.levels>=1))
-    stop("contour.levels must be between 0 and 1")
-  
-  iyaxis <- charmatch(yaxis,
-                     c("se", "size", "invvar", "invse"),
-                     nomatch = NA)
-  if(is.na(iyaxis) | iyaxis==0)
-    stop("yaxis should be \"se\", \"size\", \"invvar\", or \"invse\"")
-  ##
-  yaxis <- c("se", "size", "invvar", "invse")[iyaxis]
-  
-  seTE[is.infinite(seTE)] <- NA
-  
+  ##  
   if ( yaxis == "se" )
     seTE.min <- 0
   else
@@ -103,8 +130,6 @@ funnel.meta <- function(x,
     ##
     if (log=="") log <- "x"
   }
-  
-  
   ##
   ## y-value: weight
   ##
@@ -121,10 +146,8 @@ funnel.meta <- function(x,
     else if (length(x$n)>0)
       weight <- floor(x$n)
     else
-      stop("no information on sample size available in object '",
-           deparse(substitute(x)), "'")
-  
-  
+      stop("No information on sample size available in object '",
+           deparse(substitute(x)), "'.")
   ##
   ## x-axis: labels / xlim
   ##
@@ -143,8 +166,6 @@ funnel.meta <- function(x,
     xlim <- TE.xlim
   else if (is.null(xlim))
     xlim <- range(TE, na.rm=TRUE)
-  
-  
   ##
   ## y-axis: labels / ylim
   ##
@@ -156,13 +177,18 @@ funnel.meta <- function(x,
   if (is.null(ylim) & yaxis=="se") ylim <- c(max(weight, na.rm=TRUE), 0)
   if (is.null(ylim)              ) ylim <- range(weight, na.rm=TRUE)
   
+
+  ##
+  ##
+  ## (5) Produce funnel plot
   ##
-  ## plot
   ##
   plot(TE, weight, type="n",
        xlim=xlim, ylim=ylim, xlab=xlab, ylab=ylab,
        axes=axes, log=log, ...)
-  
+  ##
+  ## Add contour shades (enhanced funnel plots)
+  ##
   if (!is.null(contour.levels) & yaxis!="size"){
     ##
     if (missing(col.contour))
@@ -273,40 +299,54 @@ funnel.meta <- function(x,
               col=col.contour[j], border=FALSE)
     }
   }
-  
+  ##
+  ## Add results for individual studies
+  ##
   if (is.null(text))
     points(TE, weight, pch=pch, cex=cex, col=col, bg=bg)
   else
     text(TE, weight, labels=text, cex=cex, col=col)
-  
+  ##
+  ## Add results for meta-analysis
+  ##
   if (comb.fixed)
     lines(c(TE.fixed, TE.fixed), range(ylim), lty=lty.fixed, lwd=lwd.fixed, col=col.fixed)
-  
+  ##
   if (comb.random)
     lines(c(TE.random, TE.random), range(ylim), lty=lty.random, lwd=lwd.random, col=col.random)
+  ##
+  ## Add approximate confidence intervals
+  ##
+  if (!is.null(level))
+    if (yaxis=="se"){
+      points(ciTE$lower, seTE.seq, type="l", lty=lty.fixed, lwd=lwd.fixed)
+      points(ciTE$upper, seTE.seq, type="l", lty=lty.fixed, lwd=lwd.fixed)
+    }
+    else if (yaxis=="invvar"){
+      points(ciTE$lower, 1/seTE.seq^2, type="l", lty=lty.fixed, lwd=lwd.fixed)
+      points(ciTE$upper, 1/seTE.seq^2, type="l", lty=lty.fixed, lwd=lwd.fixed)
+    }
+    else if (yaxis=="invse"){
+      points(ciTE$lower, 1/seTE.seq, type="l", lty=lty.fixed, lwd=lwd.fixed)
+      points(ciTE$upper, 1/seTE.seq, type="l", lty=lty.fixed, lwd=lwd.fixed)
+    }
+  ##
+  ## Add study labels
+  ##
+  if (!is.logical(studlab) && length(studlab)>0)
+    text(TE, weight, labels=studlab, pos=2, cex=cex.studlab)  
   
-  if (!is.null(level) & yaxis=="se"){
-    points(ciTE$lower, seTE.seq, type="l", lty=lty.fixed, lwd=lwd.fixed)
-    points(ciTE$upper, seTE.seq, type="l", lty=lty.fixed, lwd=lwd.fixed)
-  }
   
-  if (!is.null(level) & yaxis=="invvar"){
-    points(ciTE$lower, 1/seTE.seq^2, type="l", lty=lty.fixed, lwd=lwd.fixed)
-    points(ciTE$upper, 1/seTE.seq^2, type="l", lty=lty.fixed, lwd=lwd.fixed)
-  }
-  
-  if (!is.null(level) & yaxis=="invse"){
-    points(ciTE$lower, 1/seTE.seq, type="l", lty=lty.fixed, lwd=lwd.fixed)
-    points(ciTE$upper, 1/seTE.seq, type="l", lty=lty.fixed, lwd=lwd.fixed)
-  }
-
+  ##
+  ##
+  ## (6) Return contour levels (if not NULL)
+  ##
+  ##
   if (!is.null(contour.levels) & yaxis!="size")
     res <- list(col.contour=col.contour)
   else
     res <- NULL
-
-  if (!is.logical(studlab) && length(studlab)>0)
-    text(TE, weight, labels=studlab, pos=2, cex=cex.studlab)  
+  
   
   invisible(res)
 }
