@@ -30,7 +30,7 @@ labbe.metabin <- function(x,
   if(length(pc) != length(pe))
     stop("event rates must be of same length")
   
-  sm <- x$sm
+  sm <- setchar(sm, c("OR", "RD", "RR", "ASD"))
   
   if (missing(weight))
     weight <- ifelse(comb.random & !comb.fixed, "random", "fixed")
@@ -147,7 +147,7 @@ labbe.metabin <- function(x,
       }
     }
     ##
-    if (sm=="AS" & length(TE.fixed)>0){
+    if (sm=="ASD" & length(TE.fixed)>0){
       for (i in 1:length(TE.fixed)){
         y.line <- sin(asin(sqrt(x.line)) + TE.fixed[i])^2
         sel <- min(ylim) <= y.line & y.line <= max(ylim)
@@ -192,7 +192,7 @@ labbe.metabin <- function(x,
       }
     }
     ##
-    if (sm=="AS" & length(TE.random)>0){
+    if (sm=="ASD" & length(TE.random)>0){
       for (i in 1:length(TE.random)){
         y.line <- sin(asin(sqrt(x.line)) + TE.random[i])^2
         sel <- min(ylim) <= y.line & y.line <= max(ylim)
