@@ -97,7 +97,7 @@ argslist <- c("level", "level.comb", "comb.fixed", "comb.random",
               "incr", "allincr", "addincr",
               "method", "allstudies", "MH.exact",
               "RR.cochrane", "print.CMH",
-              "pooledvar", "method.ci",
+              "pooledvar", "method.smd", "sd.glass", "method.ci",
               "label.e", "label.c", "label.left", "label.right")
 setOption("argslist", argslist)
 ##
@@ -145,6 +145,8 @@ setOption("print.CMH", FALSE)
 ## Additional setting for R function metacont
 ##
 setOption("pooledvar", FALSE)
+setOption("method.smd", "Hedges")
+setOption("sd.glass", "control")
 ##
 ## Additional setting for R function metaprop
 ##
