@@ -9,6 +9,7 @@ trimfill.default <- function(x, seTE, left=NULL, ma.fixed=TRUE,
                              backtransf=TRUE,
                              silent=TRUE, ...){
   
+  
   TE <- x
   ##
   if (is.null(sm)) sm <- ""
@@ -18,6 +19,19 @@ trimfill.default <- function(x, seTE, left=NULL, ma.fixed=TRUE,
                      sep=", ")
   
   
+  ##
+  ## Check arguments
+  ##
+  type <- setchar(type, c("L", "R"))
+  ##
+  chklevel(level)
+  chklevel(level.comb)
+  chklevel(level.predict)
+  ##
+  chklogical(comb.fixed)
+  chklogical(comb.random)
+  
+  
   if(length(TE) != length(seTE))
     stop("length of argument TE and seTE must be equal")
   ##
@@ -41,29 +55,6 @@ trimfill.default <- function(x, seTE, left=NULL, ma.fixed=TRUE,
   }
   
   
-  if (match(type, c("L", "R"), nomatch=0) == 0)
-    stop("type must be either 'L' or 'R'")
-  
-  
-  ##
-  ## Check for levels of confidence interval
-  ##
-  if (!is.numeric(level) | length(level)!=1)
-    stop("parameter 'level' must be a numeric of length 1")
-  if (level <= 0 | level >= 1)
-    stop("parameter 'level': no valid level for confidence interval")
-  ##
-  if (!is.numeric(level.comb) | length(level.comb)!=1)
-    stop("parameter 'level.comb' must be a numeric of length 1")
-  if (level.comb <= 0 | level.comb >= 1)
-    stop("parameter 'level.comb': no valid level for confidence interval")
-  ##
-  if (!is.numeric(level.predict) | length(level.predict)!=1)
-    stop("parameter 'level.predict' must be a numeric of length 1")
-  if (level.predict <= 0 | level.predict >= 1)
-    stop("parameter 'level.predict': no valid level for confidence interval")
-  
-  
   if (is.null(left))
     left <- as.logical(sign(metabias(TE, seTE, method="linreg", k.min=3)$estimate[1])==1)
   ##
