@@ -34,6 +34,8 @@ update.meta <- function(object,
                         n.e=object$n.e,
                         n.c=object$n.c,
                         pooledvar=object$pooledvar,
+                        method.smd=object$method.smd,
+                        sd.glass=object$sd.glass,
                         method.ci=object$method.ci,
                         byvar=object$byvar,
                         bylab=object$bylab,
@@ -316,6 +318,7 @@ update.meta <- function(object,
                   data=data, subset=subset,
                   ##
                   sm=sm, pooledvar=pooledvar,
+                  method.smd=method.smd, sd.glass=sd.glass,
                   ##
                   level=level, level.comb=level.comb,
                   comb.fixed=comb.fixed, comb.random=comb.random,
